Origin
------

.. autosimple:: swh.web.api.views.origin.api_origin

.. autosimple:: swh.web.api.views.origin.api_origin_search

.. autosimple:: swh.web.api.views.origin.api_origin_visits

.. autosimple:: swh.web.api.views.origin.api_origin_visit
